"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const file_store_1 = require("../../../components/file/file-store");
const file_temp_1 = require("../../../libs/file-temp");
const testing_1 = require("../../../testing");
const sub_1 = require("./sub");
let sub;
const tmp = new file_temp_1.FileTemp();
beforeEach(async () => {
    await testing_1.Testing.reset();
});
afterEach(async () => {
    await sub.dispose();
    tmp.remove();
});
test('Listen to handle jobs in queue', async () => {
    const jobData = { foo: 'bar' };
    sub = await testing_1.Testing.newElement(sub_1.Sub, {
        address: '0.0.0.0:4001',
        queue: {
            file: tmp.file
        },
        runs: [
            {
                vars: {
                    jobData: '${this.parentState.jobData}'
                }
            },
            {
                "http/jobs'stop": null
            }
        ]
    });
    setTimeout(async () => {
        await fetch('http://0.0.0.0:4001', {
            method: 'POST',
            body: JSON.stringify(jobData)
        });
    }, 1000);
    await sub.exec();
    expect(testing_1.Testing.vars.jobData).toEqual(jobData);
    expect(tmp.isExisted).toBe(true);
});
test('Test storage is ref ID', async () => {
    const jobData = { foo: 'bar' };
    const fs = await testing_1.Testing.newElement(file_store_1.FileStore, {
        id: 'fileStorage',
        path: tmp.file,
        initData: []
    });
    await fs.exec();
    sub = await testing_1.Testing.newElement(sub_1.Sub, {
        address: '0.0.0.0:4002',
        queue: {
            storage: '${vars.fileStorage}'
        },
        runs: [
            {
                vars: {
                    jobData: '${this.parentState.jobData}'
                }
            },
            {
                "http/jobs'stop": null
            }
        ]
    });
    const t = new Promise((resolve, reject) => {
        setTimeout(async () => {
            try {
                await fetch('http://0.0.0.0:4002', {
                    method: 'POST',
                    body: JSON.stringify(jobData)
                });
            }
            catch (err) {
                reject(err);
            }
            resolve(undefined);
        }, 5000);
    });
    await sub.exec();
    await t;
    expect(testing_1.Testing.vars.jobData).toEqual(jobData);
    expect(tmp.isExisted).toBe(true);
    await fs.dispose();
});
//# sourceMappingURL=sub.spec.js.map